Plus-Minus classifier
plusminus.fit(XX, YY, ...)a matrix of observations. NAs and Infs are not allowed.
a vector. NAs and Infs are not allowed.
additional arguments. Currently ignored.
An object of class plusminus is returned. The object contains all components returned by the underlying fit function. In addition, it contains the following:
regression coefficients
response values
scaled predictors
This function should not be called directly, but through plusminusFit with the argument method="plusminus". It implements the Plus-Minus algorithm.
Zhao et al. (2014) Mas-o-menos: a simple sign averaging method for discriminationin genomic data analysis. Bioinformatics, 30(21):3062-3069.